@@ -19,7 +19,7 @@
 #'   If TRUE, the value returned is the ID of the command to look for (from Opal 2.1).
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.execute(o, "x <- 'foo'")
 #' opal.execute(o, "ls()")
 #' opal.logout(o)
@@ -47,7 +47,7 @@ opal.execute <- function(opal, script, async=FALSE) {
 #'   If TRUE, the value returned is the ID of the command to look for (from Opal 2.1).
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.execute.source(o, "myscript.R")
 #' opal.logout(o)
 #' }
@@ -62,8 +62,7 @@ opal.execute.source <- function(opal, path, async=FALSE) {
   if(is.list(opal)){
     lapply(opal, function(o){opal.execute.source(o, path, async=async)})
   } else {
-    tmp <- paste0("/tmp/", sample(1000:9999, 1), "/")
-    opal.file_mkdir(opal, tmp)
+    tmp <- opal.file_mkdir_tmp(opal)
     opal.file_upload(opal, path, tmp)
     filename <- basename(path)
     opal.file_write(opal, paste0(tmp, filename))
@@ -85,7 +84,7 @@ opal.execute.source <- function(opal, path, async=FALSE) {
 #' @param pkg Package name.
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.load_package(o, 'stats')
 #' opal.logout(o)
 #' }
@@ -103,7 +102,7 @@ opal.load_package <- function(opal, pkg) {
 #' @param pkg Package name.
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.unload_package(o, 'stats')
 #' opal.logout(o)
 #' }
