@@ -72,7 +72,7 @@ opal.login <- function(username=getOption("opal.username"), password=getOption("
 #' @param save Save the workspace with given identifier (default value is FALSE, current session ID if TRUE).
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.logout(o)
 #' }
 #' @export
@@ -121,7 +121,7 @@ print.opal <- function(x, ...) {
 #' @param version The semantic version string to be compared.
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.version_compare(o, "2.6.0")
 #' opal.logout(o)
 #' }
@@ -160,7 +160,7 @@ opal.version_compare <- function(opal, version) {
 #' @import httr
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.get(o, 'project', 'datashield')
 #' opal.logout(o)
 #' }
@@ -182,7 +182,7 @@ opal.get <- function(opal, ..., query=list(), callback=NULL) {
 #' @import httr
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.post(o, 'some', 'resources', body='{"some":"value"}')
 #' opal.logout(o)
 #' }
@@ -204,7 +204,7 @@ opal.post <- function(opal, ..., query=list(), body='', contentType='application
 #' @import httr
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.put(o, 'some', 'resource', 'toupdate', body='{"some":"value"}')
 #' opal.logout(o)
 #' }
@@ -224,7 +224,7 @@ opal.put <- function(opal, ..., query=list(), body='', contentType='application/
 #' @import httr
 #' @examples 
 #' \dontrun{
-#' o <- opal.login('administrator','password','https://opal-demo.obiba.org')
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
 #' opal.delete(o, 'some', 'resource')
 #' opal.logout(o)
 #' }
@@ -561,4 +561,21 @@ opal.delete <- function(opal, ..., query=list(), callback=NULL) {
 #' @keywords internal
 .is.verbose <- function() {
   getOption("verbose", FALSE)
+}
+
+#' Permsissions (ACLs) into a data frame.
+#' @keywords internal
+.aclsToDataFrame <- function(perms, acls) {
+  subject <- c()
+  type <- c()
+  permission <- c()
+  if (!is.null(acls) && length(acls)>0) {
+    for (i in 1:length(acls)) {
+      acl <- acls[[i]]
+      subject <- append(subject, acl$subject$principal)
+      type <- append(type, tolower(acl$subject$type))
+      permission <- append(permission, perms[[acl$actions[[1]]]])
+    }
+  }
+  data.frame(subject, type, permission, stringsAsFactors = FALSE)
 }
\ No newline at end of file
